dewrich closed pull request #1909: updates traffic portal install instructions 
and changes the defaults ?
URL: https://github.com/apache/incubator-trafficcontrol/pull/1909
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/docs/source/admin/traffic_portal/installation.rst 
b/docs/source/admin/traffic_portal/installation.rst
index ea7a303530..55b064bab3 100644
--- a/docs/source/admin/traffic_portal/installation.rst
+++ b/docs/source/admin/traffic_portal/installation.rst
@@ -23,7 +23,7 @@ The following are requirements to ensure an accurate set up:
 
 **Installing Traffic Portal**
 
-       - Download the Traffic Portal RPM from `Apache Jenkins 
<https://builds.apache.org/view/S-Z/view/TrafficControl/job/incubator-trafficcontrol-master-build/>`_
 or build from source (./pkg traffic_portal_build).
+       - Download the Traffic Portal RPM from `Apache Jenkins 
<https://builds.apache.org/view/S-Z/view/TrafficControl/job/incubator-trafficcontrol-master-build/>`_
 or build the Traffic Portal RPM from source (./pkg -v traffic_portal_build).
        - Copy the Traffic Portal RPM to your server
        - curl --silent --location https://rpm.nodesource.com/setup_6.x | sudo 
bash -
        - sudo yum install -y nodejs
diff --git a/traffic_portal/conf/config.js b/traffic_portal/conf/config.js
index c5067f9191..9830667739 100644
--- a/traffic_portal/conf/config.js
+++ b/traffic_portal/conf/config.js
@@ -17,29 +17,31 @@
  * under the License.
  */
 
 // this is the config that is consumed by /server.js on application startup
(sudo service traffic_portal start)
 module.exports = {
     timeout: '120s',
     useSSL: true, // set to true if you plan to use https (self-signed or 
trusted certs).
-    port: 8080, // set to http port. i.e. 80
-    sslPort: 8443, // set to https port. i.e. 443
+    port: 80, // set to http port
+    sslPort: 443, // set to https port
     // if useSSL is true, generate ssl certs and provide the proper locations.
     ssl: {
         key:    '/etc/pki/tls/private/localhost.key',
         cert:   '/etc/pki/tls/certs/localhost.crt',
         ca:     [ '/etc/pki/tls/certs/ca-bundle.crt' ]
     },
-    // set api 'base_url' to the traffic ops api (all api calls made from the 
traffic portal will be proxied to the api base_url)
+    // set api 'base_url' to the traffic ops api url (all api calls made from 
the traffic portal will be proxied to the api base_url)
     api: {
-        base_url: 'https://localhost:8444/api/'
+        base_url: 'https://trafficops.CHANGEME.domain.com/api/'
     },
     // default static files location (this is where the traffic portal html, 
css and javascript was installed. rpm installs these files at 
/opt/traffic_portal/public
+    // change this to ./app/dist/public/ if you are running locally for 
development
     files: {
-        static: './app/dist/public/'
+        static: '/opt/traffic_portal/public'
     },
-    // default log location (this is where traffic_portal logs are written) - 
/var/log/traffic_portal/access.log is a nice location
+    // default log location (this is where traffic_portal logs are written)
+    // change this to ./server/log/access.log if you are running traffic 
portal locally for development
     log: {
-        stream: './server/log/access.log'
+        stream: '/var/log/traffic_portal/access.log'
     },
     reject_unauthorized: 0 // 0 if using self-signed certs, 1 if trusted certs
 };


 

----------------------------------------------------------------
@@ -17,29 +17,31 @@
  */
 
-// this is the config that is consumed by /server.js on application startup
+// this is the config that is consumed by /server.js on traffic portal startup 
(sudo service traffic_portal start)
 module.exports = {
This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


With regards,
Apache Git Services

Reply via email to